Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(322)

Unified Diff: ui/views/style/platform_style.h

Issue 2399603002: views: don't send OnKeypressUnhandled for all keys (Closed)
Patch Set: OnKeypressUnhandled -> OnEditFailed Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/views/controls/textfield/textfield.cc ('k') | ui/views/style/platform_style.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/style/platform_style.h
diff --git a/ui/views/style/platform_style.h b/ui/views/style/platform_style.h
index 8405cb2009a6d2284b297e80343f7efd728c9cde..3e390abe1f3c63a8f346cc6f2f05e84cf0be0712 100644
--- a/ui/views/style/platform_style.h
+++ b/ui/views/style/platform_style.h
@@ -86,9 +86,9 @@ class VIEWS_EXPORT PlatformStyle {
static std::unique_ptr<Border> CreateThemedLabelButtonBorder(
LabelButton* button);
- // Called whenever a textfield keypress is unhandled for any reason. Gives
- // visual/audio feedback about the unhandled key if platform-appropriate.
- static void OnTextfieldKeypressUnhandled();
+ // Called whenever a textfield edit fails. Gives visual/audio feedback about
+ // the failed edit if platform-appropriate.
+ static void OnTextfieldEditFailed();
private:
DISALLOW_IMPLICIT_CONSTRUCTORS(PlatformStyle);
« no previous file with comments | « ui/views/controls/textfield/textfield.cc ('k') | ui/views/style/platform_style.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698